@@ -66,11 +66,17 @@ has message => (
 );
 
 # HTTP status code, response, request
-has [ qw/ code response request / ] => (
+has [ qw/ code response / ] => (
     is       => 'ro',
     required => 0,
 );
 
+has [ qw/ request / ] => (
+    is       => 'ro',
+    required => 0,
+    default  => sub { $Business::Fixflo::Client::request_data || undef },
+);
+
 =head1 METHODS
 
 =head2 description
